Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5)

Unified Diff: client/tools/buildbot_annotated_steps.py

Issue 10448046: Use utils/compiler/buildbot.py instead of the script in frog/scripts. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | frog/scripts/buildbot_annotated_steps.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: client/tools/buildbot_annotated_steps.py
diff --git a/client/tools/buildbot_annotated_steps.py b/client/tools/buildbot_annotated_steps.py
index 21c44301ee6f7bc352ba5e138313674c6553dfa2..1c224fd566299630dc07792ddf7d64409a728440 100644
--- a/client/tools/buildbot_annotated_steps.py
+++ b/client/tools/buildbot_annotated_steps.py
@@ -115,18 +115,18 @@ def ProcessTools(mode, name, version):
return subprocess.call(cmds, env=local_env)
-def ProcessFrog(name):
+def ProcessCompiler(name):
'''
build and test experimental frog build
'''
- print 'ProcessFrog'
+ print 'ProcessCompiler'
has_shell=False
if 'windows' in name:
# In Windows we need to run in the shell, so that we have all the
# environment variables available.
has_shell=True
return subprocess.call([sys.executable,
- os.path.join('frog', 'scripts', 'buildbot_annotated_steps.py')],
+ os.path.join('utils', 'compiler', 'buildbot.py')],
env=os.environ, shell=has_shell)
def main():
@@ -144,7 +144,7 @@ def main():
if name.startswith('dart-editor'):
status = ProcessTools('release', name, version)
else:
- status = ProcessFrog(name)
+ status = ProcessCompiler(name)
if status:
print '@@@STEP_FAILURE@@@'
« no previous file with comments | « no previous file | frog/scripts/buildbot_annotated_steps.py » ('j') | no next file with comments »
@@ -115,18 +115,18 @@ def ProcessTools(mode, name, version):
'''
- build and test experimental frog build
+ build and test the compiler
'''

Powered by Google App Engine
This is Rietveld 408576698